"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorHandler = void 0;
const http_status_codes_1 = require("http-status-codes");
function errorHandler(logger) {
    return async function errorHandlerMiddleware(context, next) {
        try {
            await next();
        }
        catch (error) {
            let statusCode = http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR;
            let reason = http_status_codes_1.ReasonPhrases.INTERNAL_SERVER_ERROR;
            let stack;
            if (error instanceof Object) {
                if ('status' in error) {
                    statusCode = Number(error.status);
                }
                if ('statusCode' in error) {
                    statusCode = Number(error.statusCode);
                }
            }
            if (error instanceof Error) {
                stack = String(error.stack);
            }
            context.status = statusCode;
            context.body = { statusCode, reason, error };
            logger.error(`${statusCode} ${reason}`, { error: `${error}`, stack });
        }
    };
}
exports.errorHandler = errorHandler;
//# sourceMappingURL=errorHandler.js.map